@@ -6,6 +6,16 @@
 # Follows is Facebook graph fields to get data
 # =============================================
 
+BUSINESS_PUBLIC_FIELDS = [
+    "id",
+    "name",
+    "link",
+    "created_time",
+    "updated_time",
+    "verification_status",
+    "profile_picture_uri",
+]
+
 USER_PUBLIC_FIELDS = [
     "id",
     "first_name",
@@ -40,6 +50,8 @@ PAGE_PUBLIC_FIELDS = [
     "website",
 ]
 
+SEARCH_PAGES_PUBLIC_FIELDS = ["id", "name", "location", "link", "verification_status"]
+
 GROUP_PUBLIC_FIELDS = [
     "id",
     "name",
@@ -101,6 +113,17 @@ PHOTO_PUBLIC_FIELDS = ["id", "created_time", "name", "updated_time", "link"]
 
 ALBUM_PUBLIC_FIELDS = ["id", "created_time", "count", "name", "updated_time", "link"]
 
+APPLICATION_PUBLIC_FIELDS = [
+    "id",
+    "category",
+    "description",
+    "link",
+    "name",
+    "namespace",
+]
+
+APPLICATION_ACCOUNT_PUBLIC_FIELDS = ["id", "login_url"]
+
 VIDEO_PUBLIC_FIELDS = [
     "id",
     "created_time",
